#ifndef SETUPDIALOG_H
#define SETUPDIALOG_H

#include <QDialog>
#include <QDialogButtonBox>

namespace Ui {
    class SetupDialog;
}

class SetupDialog : public QDialog
{
    Q_OBJECT

public:
    explicit SetupDialog(QWidget *parent = 0);
    ~SetupDialog();
    void save();
    void load();

private slots:
    void on_screenDimTimeoutSlider_valueChanged(int value);
    void on_screenDimPercentSlider_valueChanged(int value);
    void on_screenLockTimeoutSlider_valueChanged(int value);
    void on_notificationTimeoutSlider_valueChanged(int value);
    void on_buttonBox_clicked(QAbstractButton* button);

private:
    void load(bool restore_defaults);
    Ui::SetupDialog *ui;
};

#endif // SETUPDIALOG_H
